@@ -27,21 +27,18 @@
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KActionMenu>
-#include <KCmdLineArgs>
 #include <KShortcutsDialog>
 #include <KLocalizedString>
 
 #include <QMenu>
 #include <QMenuBar>
 #include <KMessageBox>
-#include <KToggleFullScreenAction>
 #include <KStandardAction>
 #include <KStandardGuiItem>
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 #include <KNotifyConfigWidget>
 #include <KConfigDialog>
-#include <KApplication>
 #include <KIconLoader>
 
 // Konsole
@@ -67,6 +64,7 @@ MainWindow::MainWindow()
     , _pluggedController(0)
     , _menuBarInitialVisibility(true)
     , _menuBarInitialVisibilityApplied(false)
+    , _useTransparency(false)
 {
     if (!KonsoleSettings::saveGeometryOnExit()) {
         // If we are not using the global Konsole save geometry on exit,
@@ -131,9 +129,7 @@ MainWindow::MainWindow()
 
 void MainWindow::updateUseTransparency()
 {
-    const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-
-    bool useTranslucency = KWindowSystem::compositingActive() && args->isSet("transparency");
+    bool useTranslucency = KWindowSystem::compositingActive() && _useTransparency;
 
     setAttribute(Qt::WA_TranslucentBackground, useTranslucency);
     setAttribute(Qt::WA_NoSystemBackground, false);
@@ -275,7 +271,7 @@ void MainWindow::updateWindowCaption()
 
 void MainWindow::updateWindowIcon()
 {
-    if (_pluggedController)
+    if (_pluggedController && !_pluggedController->icon().isNull())
         setWindowIcon(_pluggedController->icon());
 }
 
@@ -499,7 +495,7 @@ Session* MainWindow::createSSHSession(Profile::Ptr profile, const QUrl& url)
         sshCommand += url.host();
     }
 
-    session->sendText(sshCommand + '\r');
+    session->sendTextToTerminal(sshCommand, '\r');
 
     // create view before starting the session process so that the session
     // doesn't suffer a change in terminal size right after the session
@@ -769,6 +765,11 @@ void MainWindow::setShowQuickButtons(bool show)
     _viewManager->setShowQuickButtons(show);
 }
 
+void MainWindow::setTransparency(bool useTransparency)
+{
+    _useTransparency = useTransparency;
+}
+
 void MainWindow::activateMenuBar()
 {
     const QList<QAction*> menuActions = menuBar()->actions();
@@ -823,6 +824,8 @@ void MainWindow::showEvent(QShowEvent* aEvent)
         menuBar()->setVisible(_menuBarInitialVisibility);
         _toggleMenuBarAction->setChecked(_menuBarInitialVisibility);
         _menuBarInitialVisibilityApplied = true;
+        if(!KonsoleSettings::saveGeometryOnExit())
+            resize(sizeHint());
     }
 
     // Call parent method
