@@ -347,35 +347,22 @@ void Screen::setDefaultMargins()
 /*
    Clarifying rendition here and in the display.
 
-   currently, the display's color table is
-   0       1       2 .. 9    10 .. 17
-   dft_fg, dft_bg, dim 0..7, intensive 0..7
+   The rendition attributes are
 
-   _currentForeground, _currentBackground contain values 0..8;
-   - 0    = default color
-   - 1..8 = ansi specified color
+   attribute
+   --------------
+   RE_UNDERLINE
+   RE_BLINK
+   RE_BOLD
+   RE_REVERSE
+   RE_TRANSPARENT
+   RE_FAINT
+   RE_STRIKEOUT
+   RE_CONCEAL
+   RE_OVERLINE
 
-   re_fg, re_bg contain values 0..17
-   due to the TerminalDisplay's color table
-
-   rendition attributes are
-
-   attr           widget screen
-   -------------- ------ ------
-   RE_UNDERLINE     XX     XX    affects foreground only
-   RE_BLINK         XX     XX    affects foreground only
-   RE_BOLD          XX     XX    affects foreground only
-   RE_REVERSE       --     XX
-   RE_TRANSPARENT   XX     --    affects background only
-   RE_INTENSIVE     XX     --    affects foreground only
-
-   Note that RE_BOLD is used in both widget
-   and screen rendition. Since xterm/vt102
-   is to poor to distinguish between bold
-   (which is a font attribute) and intensive
-   (which is a color attribute), we translate
-   this and RE_BOLD in falls eventually apart
-   into RE_BOLD and RE_INTENSIVE.
+   Depending on settings, bold may be rendered as a heavier font
+   in addition to a different color.
    */
 
 void Screen::reverseRendition(Character& p) const
@@ -398,8 +385,13 @@ void Screen::updateEffectiveRendition()
         _effectiveBackground = _currentBackground;
     }
 
-    if (_currentRendition & RE_BOLD)
-        _effectiveForeground.setIntensive();
+    if (_currentRendition & RE_BOLD) {
+        if (!(_currentRendition & RE_FAINT))
+            _effectiveForeground.setIntensive();
+    } else {
+        if (_currentRendition & RE_FAINT)
+            _effectiveForeground.setFaint();
+    }
 }
 
 void Screen::copyFromHistory(Character* dest, int startLine, int count) const
@@ -513,14 +505,18 @@ QVector<LineProperty> Screen::getLineProperties(int startLine , int endLine) con
     return result;
 }
 
-void Screen::reset(bool clearScreen)
+void Screen::reset()
 {
+    // Clear screen, but preserve the current line
+    scrollUp(0, _cuY);
+    _cuY = 0;
+
+    _currentModes[MODE_Origin] = false;
+    _savedModes[MODE_Origin] = false;
+
     setMode(MODE_Wrap);
     saveMode(MODE_Wrap);      // wrap at end of margin
 
-    resetMode(MODE_Origin);
-    saveMode(MODE_Origin);  // position refer to [1,1]
-
     resetMode(MODE_Insert);
     saveMode(MODE_Insert);  // overstroke
 
@@ -531,11 +527,11 @@ void Screen::reset(bool clearScreen)
     _topMargin = 0;
     _bottomMargin = _lines - 1;
 
+    // Other terminal emulators reset the entire scroll history during a reset
+//    setScroll(getScroll(), false);
+
     setDefaultRendition();
     saveCursor();
-
-    if (clearScreen)
-        clear();
 }
 
 void Screen::clear()
@@ -634,34 +630,34 @@ void Screen::displayCharacter(unsigned short c)
     // putting the cursor one right to the last column of the screen.
 
     int w = konsole_wcwidth(c);
-    if (w < 0)
+
+    if (w < 0) {
+        // Non-printable character
         return;
-    else if (w == 0) {
-        if (QChar(c).category() != QChar::Mark_NonSpacing)
+    } else if (w == 0) {
+        const QChar::Category category = QChar(c).category();
+        if (category != QChar::Mark_NonSpacing && category != QChar::Letter_Other) {
             return;
-        int charToCombineWithX = -1;
-        int charToCombineWithY = -1;
-        if (_cuX == 0) {
-            // We are at the beginning of a line, check
-            // if previous line has a character at the end we can combine with
-            if (_cuY > 0 && _columns == _screenLines[_cuY - 1].size()) {
-                charToCombineWithX = _columns - 1;
-                charToCombineWithY = _cuY - 1;
+        }
+        // Find previous "real character" to try to combine with
+        int charToCombineWithX = _cuX;
+        int charToCombineWithY = _cuY;
+        do {
+            if (charToCombineWithX > 0) {
+                charToCombineWithX--;
+            } else if (charToCombineWithY > 0) { // Try previous line
+                charToCombineWithY--;
+                charToCombineWithX = _screenLines[charToCombineWithY].length() - 1;
             } else {
-                // There is nothing to combine with
-                // TODO Seems gnome-terminal shows the characters alone
-                // might be worth investigating how to do that
+                // Give up
                 return;
             }
-        } else {
-            charToCombineWithX = _cuX - 1;
-            charToCombineWithY = _cuY;
-        }
 
-        // Prevent "cat"ing binary files from causing crashes.
-        if (charToCombineWithX >= _screenLines[charToCombineWithY].size()) {
-            return;
-        }
+            // Failsafe
+            if (charToCombineWithX < 0) {
+                return;
+            }
+        } while(!_screenLines[charToCombineWithY][charToCombineWithX].isRealCharacter);
 
         Character& currentChar = _screenLines[charToCombineWithY][charToCombineWithX];
         if ((currentChar.rendition & RE_EXTENDED_CHAR) == 0) {
@@ -986,13 +982,13 @@ void Screen::clearEntireLine()
     clearImage(loc(0, _cuY), loc(_columns - 1, _cuY), ' ');
 }
 
-void Screen::setRendition(int rendention)
+void Screen::setRendition(RenditionFlags rendention)
 {
     _currentRendition |= rendention;
     updateEffectiveRendition();
 }
 
-void Screen::resetRendition(int rendention)
+void Screen::resetRendition(RenditionFlags rendention)
 {
     _currentRendition &= ~rendention;
     updateEffectiveRendition();
