@@ -43,6 +43,7 @@
 
 namespace Konsole
 {
+
 class TerminalCharacterDecoder;
 class TerminalDisplay;
 class HistoryType;
@@ -270,14 +271,14 @@ public:
      *
      * @see Character::rendition
      */
-    void setRendition(int rendition);
+    void setRendition(RenditionFlags rendition);
     /**
      * Disables the given @p rendition flag.  Rendition flags control the appearance
      * of characters on the screen.
      *
      * @see Character::rendition
      */
-    void resetRendition(int rendition);
+    void resetRendition(RenditionFlags rendition);
 
     /**
      * Sets the cursor's foreground color.
@@ -334,7 +335,7 @@ public:
      * If @p clearScreen is true then the screen contents are erased entirely,
      * otherwise they are unaltered.
      */
-    void reset(bool clearScreen = true);
+    void reset();
 
     /**
      * Displays a new character at the current cursor position.
@@ -449,6 +450,7 @@ public:
      * be inserted into the returned text at the end of each terminal line.
      * @param trimTrailingSpaces Specifies whether trailing spaces should be
      * trimmed in the returned text.
+     * @param html Specifies if returned text should have HTML tags.
      */
     QString selectedText(bool preserveLineBreaks, bool trimTrailingSpaces = false, bool html = false) const;
 
@@ -460,6 +462,7 @@ public:
      * be inserted into the returned text at the end of each terminal line.
      * @param trimTrailingSpaces Specifies whether trailing spaces should be
      * trimmed in the returned text.
+     * @param html Specifies if returned text should have HTML tags.
      */
     QString text(int startIndex, int endIndex, bool preserveLineBreaks, bool trimTrailingSpaces = false, bool html = false) const;
 
@@ -671,7 +674,7 @@ private:
     // cursor color and rendition info
     CharacterColor _currentForeground;
     CharacterColor _currentBackground;
-    quint8 _currentRendition;
+    RenditionFlags _currentRendition;
 
     // margins ----------------
     int _topMargin;
@@ -694,7 +697,7 @@ private:
     // effective colors and rendition ------------
     CharacterColor _effectiveForeground; // These are derived from
     CharacterColor _effectiveBackground; // the cu_* variables above
-    quint8 _effectiveRendition;          // to speed up operation
+    RenditionFlags _effectiveRendition;  // to speed up operation
 
     class SavedState
     {
@@ -704,7 +707,7 @@ private:
 
         int cursorColumn;
         int cursorLine;
-        quint8 rendition;
+        RenditionFlags rendition;
         CharacterColor foreground;
         CharacterColor background;
     };
