@@ -140,7 +140,7 @@ private:
     QTextStream* _output;
     const ColorEntry* _colorTable;
     bool _innerSpanOpen;
-    quint8 _lastRendition;
+    RenditionFlags _lastRendition;
     CharacterColor _lastForeColor;
     CharacterColor _lastBackColor;
 };
