@@ -414,6 +414,21 @@ public:
         return _boldIntense;
     }
 
+    /**
+     * Specifies whether line characters will be displayed using font instead
+     * of builtin code.
+     * as bold. Defaults to false.
+     */
+    void setUseFontLineCharacters(bool value) {
+        _useFontLineCharacters = value;
+    }
+    /**
+     * Returns true if font line characters will be used.
+     */
+    bool getFontLineCharacters() const {
+        return _useFontLineCharacters;
+    }
+
     /**
      * Sets whether or not the current height and width of the
      * terminal in lines and columns is displayed whilst the widget
@@ -445,6 +460,20 @@ public:
         return _bidiEnabled;
     }
 
+    /**
+     * Enables or disables showing hints on URLs when ctrl is pressed
+     * Defaults to disabled.
+     */
+    void setEnableUrlHints(bool on) {
+        _enableShowUrlHint = on;
+    }
+    /**
+     * Returns the status of the BiDi rendering in this widget.
+     */
+    bool areUrlHintsEnabled() const {
+        return _enableShowUrlHint;
+    }
+
     /**
      * Sets the terminal screen section which is displayed in this widget.
      * When updateImage() is called, the display fetches the latest character image from the
@@ -638,6 +667,7 @@ protected:
     virtual void focusInEvent(QFocusEvent* event);
     virtual void focusOutEvent(QFocusEvent* event);
     virtual void keyPressEvent(QKeyEvent* event);
+    virtual void keyReleaseEvent(QKeyEvent* event);
     virtual void leaveEvent(QEvent* event);
     virtual void mouseDoubleClickEvent(QMouseEvent* event);
     virtual void mousePressEvent(QMouseEvent* event);
@@ -857,6 +887,8 @@ private:
     QTimer* _blinkTextTimer;
     QTimer* _blinkCursorTimer;
 
+    bool _showUrlHint;
+    bool _enableShowUrlHint;
     bool _underlineLinks;     // Underline URL and hosts on mouse hover
     bool _openLinksByDirectClick;     // Open URL and hosts by single mouse click
 
@@ -888,6 +920,7 @@ private:
     // search highlight
     TerminalImageFilterChain* _filterChain;
     QRegion _mouseOverHotspotArea;
+    bool _filterUpdateRequired;
 
     Enum::CursorShapeEnum _cursorShape;
 
@@ -902,6 +935,7 @@ private:
     InputMethodData _inputMethodData;
 
     bool _antialiasText;   // do we anti-alias or not
+    bool _useFontLineCharacters;
 
     bool _printerFriendly; // are we currently painting to a printer in black/white mode
 
