@@ -777,6 +777,7 @@ void ViewManager::applyProfileToView(TerminalDisplay* view , const Profile::Ptr
     // load font
     view->setAntialias(profile->antiAliasFonts());
     view->setBoldIntense(profile->boldIntense());
+    view->setUseFontLineCharacters(profile->useFontLineCharacters());
     view->setVTFont(profile->font());
 
     // set scroll-bar position
@@ -812,6 +813,8 @@ void ViewManager::applyProfileToView(TerminalDisplay* view , const Profile::Ptr
 
     view->setOpenLinksByDirectClick(profile->property<bool>(Profile::OpenLinksByDirectClickEnabled));
 
+    view->setEnableUrlHints(profile->property<bool>(Profile::EnableUrlHints));
+
     int middleClickPasteMode = profile->property<int>(Profile::MiddleClickPasteMode);
     if (middleClickPasteMode == Enum::PasteFromX11Selection)
         view->setMiddleClickPasteMode(Enum::PasteFromX11Selection);
