@@ -50,7 +50,19 @@ const ColorEntry CharacterColorTest::DefaultColorTable[TABLE_COLORS] = {
     ColorEntry(QColor(0x54, 0x54, 0xFF)),
     ColorEntry(QColor(0xFF, 0x54, 0xFF)),
     ColorEntry(QColor(0x54, 0xFF, 0xFF)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF))
+    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
+    // Here are faint intensities, which may not be good.
+    // faint versions
+    ColorEntry(QColor(0x00, 0x00, 0x00)),
+    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
+    ColorEntry(QColor(0x00, 0x00, 0x00)),
+    ColorEntry(QColor(0x65, 0x00, 0x00)),
+    ColorEntry(QColor(0x00, 0x65, 0x00)),
+    ColorEntry(QColor(0x65, 0x5E, 0x00)),
+    ColorEntry(QColor(0x00, 0x00, 0x65)),
+    ColorEntry(QColor(0x65, 0x00, 0x65)),
+    ColorEntry(QColor(0x00, 0x65, 0x65)),
+    ColorEntry(QColor(0x65, 0x65, 0x65))
 };
 
 void CharacterColorTest::init()
